@@ -33,13 +33,13 @@
 #include <gio/gio.h>
 #include <glibtop/mountlist.h>
 #include <glibtop/fsusage.h>
-#include <libgnome/gnome-help.h>
 
 #include "baobab.h"
 #include "baobab-treeview.h"
 #include "baobab-utils.h"
 #include "callbacks.h"
 
+
 void
 baobab_get_filesystem (baobab_fs *fs)
 {
@@ -294,7 +294,9 @@ baobab_check_dir (GFile	*file)
 		return FALSE;
 	}	
 
-	if (g_file_info_get_file_type (info) != G_FILE_TYPE_DIRECTORY) {
+	if ((g_file_info_get_file_type (info) != G_FILE_TYPE_DIRECTORY) ||
+		is_virtual_filesystem(file)) {
+		
 		char *error_msg = NULL;
 		gchar *name = NULL;
 
@@ -546,11 +548,16 @@ baobab_help_display (GtkWindow   *parent,
 		     const gchar *link_id)
 {
 	GError *error = NULL;
+	char *uri;
 	gboolean ret;
 
-	ret = gnome_help_display (file_name,
-				  link_id,
-				  &error);
+	uri = (link_id) ? 
+		g_strdup_printf ("ghelp:%s#%s", file_name, link_id) :
+		g_strdup_printf ("ghelp:%s", file_name);
+
+	ret = gtk_show_uri (gtk_window_get_screen (parent),
+			    uri, gtk_get_current_event_time (), &error);
+	g_free (uri);
 
 	if (error != NULL) {
 		GtkWidget *dialog;
@@ -574,3 +581,23 @@ baobab_help_display (GtkWindow   *parent,
 
 	return ret;
 }
+
+gboolean
+is_virtual_filesystem (GFile *file)
+{
+	gboolean ret = FALSE;
+	char *path;
+	
+	path = g_file_get_path (file);
+
+	/* FIXME: we need a better way to check virtual FS */
+	if (path != NULL) {
+		if ((strcmp (path, "/proc") == 0) ||
+		    (strcmp (path, "/sys") == 0))
+	 		ret = TRUE;
+	}
+
+	g_free (path);
+
+	return ret;
+}
