@@ -25,8 +25,6 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
-#include <libgnomeui/libgnomeui.h>
-#include <libgnomeui/gnome-ui-init.h>
 #include <gconf/gconf-client.h>
 #include <glibtop.h>
 
@@ -330,8 +328,12 @@ first_row (void)
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (baobab.tree_view), FALSE);
 	gtk_tree_store_append (baobab.model, &firstiter, NULL);
 	size = g_format_size_for_display (g_fs.used);
-	g_assert (g_fs.total != 0);
-	perc = ((gdouble) g_fs.used * 100) / (gdouble) g_fs.total;
+	if (g_fs.total == 0 && g_fs.used == 0) {
+		perc = 100.0;
+	} else {
+		g_assert (g_fs.total != 0);
+		perc = ((gdouble) g_fs.used * 100) / (gdouble) g_fs.total;
+	}
 
 	label = g_strdup_printf ("<i>%s</i>", _("Total filesystem usage:"));
 	gtk_tree_store_set (baobab.model, &firstiter,
@@ -455,9 +457,11 @@ baobab_is_excluded_location (GFile *file)
 
 	g_return_val_if_fail (file != NULL, FALSE);
 
-	for (l=baobab.excluded_locations; l != NULL; l = l->next) {	
-		if (g_file_equal(l->data, file))
+	for (l = baobab.excluded_locations; l != NULL; l = l->next) {	
+		if (g_file_equal (l->data, file)) {
 			ret = TRUE;
+			break;
+		}
 	}
 
 	return ret;
@@ -627,32 +631,43 @@ baobab_subfolderstips_toggled (GConfClient *client,
 									    NULL));
 }
 
+static void
+store_excluded_locations (void)
+{
+	GSList *l;
+	GSList *uri_list = NULL;
+
+	for (l = baobab.excluded_locations; l != NULL; l = l->next) {
+		GSList *uri_list = NULL;
+
+		uri_list = g_slist_prepend (uri_list, g_file_get_uri(l->data));
+	}
+
+	gconf_client_set_list (baobab.gconf_client,
+			       PROPS_SCAN_KEY,
+			       GCONF_VALUE_STRING, 
+			       uri_list,
+			       NULL);
+
+	g_slist_foreach (uri_list, (GFunc) g_free, NULL);
+	g_slist_free (uri_list);
+}
+
 static void
 sanity_check_excluded_locations (void)
 {
 	GFile *root;
+	GSList *l;
 
 	/* Verify if gconf wrongly contains root dir exclusion, and remove it from gconf. */
 	root = g_file_new_for_uri ("file:///");
-	if (baobab_is_excluded_location (root)) {
-		GSList *uri_list, *l;
 
-		baobab.excluded_locations = g_slist_delete_link (baobab.excluded_locations, 
-						g_slist_find (baobab.excluded_locations, 
-							      root));
-
-		for (l = baobab.excluded_locations; l != NULL; l = l->next) {
-			uri_list = g_slist_prepend (uri_list, g_file_get_uri(l->data));
+	for (l = baobab.excluded_locations; l != NULL; l = l->next) {
+		if (g_file_equal (l->data, root)) {
+			baobab.excluded_locations = g_slist_delete_link (baobab.excluded_locations, l);
+			store_excluded_locations ();
+			break;			
 		}
-		
-		gconf_client_set_list (baobab.gconf_client,
-				       PROPS_SCAN_KEY,
-				       GCONF_VALUE_STRING, 
-				       uri_list,
-				       NULL);
-
-		g_slist_foreach (uri_list, (GFunc) g_free, NULL);
-		g_slist_free (uri_list);
 	}
 
 	g_object_unref (root);
@@ -906,25 +921,31 @@ start_proc_on_command_line (GFile *file)
 int
 main (int argc, char *argv[])
 {
-	GnomeProgram *program;
 	GOptionContext *context;
+	GError *error = NULL;
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
 	context = g_option_context_new (NULL);
+	g_option_context_set_ignore_unknown_options (context, FALSE);
+	g_option_context_set_help_enabled (context, TRUE);
+	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 
-	program = gnome_program_init ("baobab", VERSION,
-				      LIBGNOMEUI_MODULE,
-				      argc, argv,
-				      GNOME_PARAM_GOPTION_CONTEXT, context,
-				      GNOME_PARAM_APP_DATADIR,
-				      BAOBAB_DATA_DIR, NULL);
+	g_option_context_parse (context, &argc, &argv, &error);
+
+	if (error) {
+		g_critical ("Unable to parse option: %s", error->message);
+		g_error_free (error);
+		g_option_context_free (context);
+
+		exit (1);
+	}
+	g_option_context_free (context);
 
 	g_set_application_name ("Baobab");
 
-	gnome_authentication_manager_init ();
 	glibtop_init ();
 
 	gtk_window_set_default_icon_name ("baobab");
@@ -995,7 +1016,5 @@ main (int argc, char *argv[])
 
 	glibtop_close ();
 
-	g_object_unref (program);
-
 	return 0;
 }
