@@ -27,29 +27,27 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <gconf/gconf-client.h>
+#include <gio/gio.h>
 
 #include "baobab.h"
-#include "baobab-graphwin.h"
 #include "baobab-treeview.h"
 #include "baobab-utils.h"
 #include "callbacks.h"
 #include "baobab-prefs.h"
 #include "baobab-remote-connect-dialog.h"
+#include "baobab-chart.h"
 
 void
 on_menuscanhome_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	start_proc_on_dir (g_get_home_dir ());
+	baobab_scan_home ();
 }
 
 void
 on_menuallfs_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	start_proc_on_dir ("file:///");
+	baobab_scan_root ();
 }
 
 void
@@ -61,7 +59,7 @@ on_menuscandir_activate (GtkMenuItem *menuitem, gpointer user_data)
 void
 on_esci1_activate (GtkObject *menuitem, gpointer user_data)
 {
-	baobab.STOP_SCANNING = TRUE;
+	baobab_stop_scan ();
 	gtk_main_quit ();
 }
 
@@ -75,8 +73,25 @@ on_about_activate (GtkMenuItem *menuitem, gpointer user_data)
 		"Igalia (rings-chart widget) <www.igalia.com>",
 		NULL
 	};
+	
+	const gchar *license =
+    	"This program is free software; you can redistribute it and/or "
+    	"modify it under the terms of the GNU General Public License as "
+    	"published by the Free Software Foundation; either version 2 of "
+    	"the License, or (at your option) any later version.\n"
+    	"\n"
+    	"This program is distributed in the hope that it will be useful, "
+    	"but WITHOUT ANY WARRANTY; without even the implied warranty of "
+    	"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU "
+    	"General Public License for more details.\n"
+    	"\n"
+    	"You should have received a copy of the GNU General Public License "
+    	"along with this program; if not, write to the Free Software "
+    	"Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA "
+    	"02111-1307, USA.\n";
 
-	static const gchar copyright[] = "Fabio Marzocca <thesaltydog@gmail.com> \xc2\xa9 2005-2006";
+
+	static const gchar copyright[] = "Fabio Marzocca <thesaltydog@gmail.com> \xc2\xa9 2005-2008";
 
 	gtk_show_about_dialog (NULL,
 			       "name", _("Baobab"),
@@ -85,10 +100,12 @@ on_about_activate (GtkMenuItem *menuitem, gpointer user_data)
 			       "version", VERSION,
 			       "copyright", copyright,
 			       "logo-icon-name", "baobab",
-			       "license", "GPL",
+			       "license", license,
 			       "authors", authors, 
 			       "translator-credits",
-			       _("translator-credits"), NULL);
+			       _("translator-credits"), 
+			       "wrap-license", TRUE,
+			        NULL);
 }
 
 void
@@ -106,14 +123,13 @@ on_menu_collapse_activate (GtkMenuItem *menuitem, gpointer user_data)
 void
 on_menu_stop_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	baobab.STOP_SCANNING = TRUE;
-	stop_scan ();
+	baobab_stop_scan ();
 }
 
 void
 on_menu_rescan_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	rescan_current_dir ();
+	baobab_rescan_current_dir ();
 }
 
 void
@@ -125,33 +141,25 @@ on_tbscandir_clicked (GtkToolButton *toolbutton, gpointer user_data)
 void
 on_tbscanhome_clicked (GtkToolButton *toolbutton, gpointer user_data)
 {
-	start_proc_on_dir (g_get_home_dir ());
+	baobab_scan_home ();
 }
 
 void
 on_tbscanall_clicked (GtkToolButton *toolbutton, gpointer user_data)
 {
-	start_proc_on_dir ("file:///");
+	baobab_scan_root ();
 }
 
 void
 on_tb_scan_remote_clicked (GtkToolButton *toolbutton, gpointer user_data)
 {
-	gint response;
 	GtkWidget *dlg;
-
-	dlg =
-	    baobab_remote_connect_dialog_new (GTK_WINDOW (baobab.window),
-					      NULL);
-	response = gtk_dialog_run (GTK_DIALOG (dlg));
+	
+	dlg = baobab_remote_connect_dialog_new (GTK_WINDOW (baobab.window),
+						NULL);
+	gtk_dialog_run (GTK_DIALOG (dlg));
 
 	gtk_widget_destroy (dlg);
-
-	while (gtk_events_pending ())
-		gtk_main_iteration ();
-
-	if (response == GTK_RESPONSE_OK)
-		start_proc_on_dir (baobab.last_scan_command->str);
 }
 
 void
@@ -163,14 +171,13 @@ on_menu_scan_rem_activate (GtkMenuItem *menuitem, gpointer user_data)
 void
 on_tbstop_clicked (GtkToolButton *toolbutton, gpointer user_data)
 {
-	baobab.STOP_SCANNING = TRUE;
-	stop_scan ();
+	baobab_stop_scan ();
 }
 
 void
 on_tbrescan_clicked (GtkToolButton *toolbutton, gpointer user_data)
 {
-	rescan_current_dir ();
+	baobab_rescan_current_dir ();
 }
 
 gboolean
@@ -184,43 +191,35 @@ on_delete_activate (GtkWidget *widget,
 void
 open_file_cb (GtkMenuItem *pmenu, gpointer dummy)
 {
-	GnomeVFSURI *vfs_uri;
+	GFile *file;
 
 	g_assert (!dummy);
 	g_assert (baobab.selected_path);
 
-	vfs_uri = gnome_vfs_uri_new (baobab.selected_path);
+	file = g_file_parse_name (baobab.selected_path);
 
-	if (!gnome_vfs_uri_exists (vfs_uri)) {
+	if (!g_file_query_exists (file, NULL)) {
 		message (_("The document does not exist."), "",
 		GTK_MESSAGE_INFO, baobab.window);
-		gnome_vfs_uri_unref (vfs_uri);
+		g_object_unref (file);
 		return;
 	}
 
-	gnome_vfs_uri_unref (vfs_uri);
-	open_file_with_application (baobab.selected_path);
-}
-
-void
-graph_map_cb (GtkMenuItem *pmenu, gchar *path_to_string)
-{
-	baobab_graphwin_create (GTK_TREE_MODEL (baobab.model),
-				path_to_string,
-				BAOBAB_GLADE_FILE,
-				COL_H_FULLPATH,
-				baobab.is_local ? COL_H_ALLOCSIZE : COL_H_SIZE,
-				-1);
-	g_free (path_to_string);
+	open_file_with_application (file);
+	g_object_unref (file);
 }
 
 void
 trash_dir_cb (GtkMenuItem *pmenu, gpointer dummy)
 {
+	GFile *file;
+
 	g_assert (!dummy);
 	g_assert (baobab.selected_path);
 
-	if (trash_file (baobab.selected_path)) {
+	file = g_file_parse_name (baobab.selected_path);
+
+	if (trash_file (file)) {
 		GtkTreeIter iter;
 		guint64 filesize;
 		GtkTreeSelection *selection;
@@ -236,11 +235,14 @@ trash_dir_cb (GtkMenuItem *pmenu, gpointer dummy)
 		if (baobab.bbEnableHomeMonitor)
 			contents_changed ();
 	}
+
+	g_object_unref (file);
 }
 
 void
-volume_changed (GnomeVFSVolumeMonitor *volume_monitor,
-		GnomeVFSVolume *volume)
+volume_changed (GVolumeMonitor *volume_monitor,
+                GVolume        *volume,
+                gpointer        user_data)
 {
 	/* filesystem has changed (mounted or unmounted device) */
 	baobab_get_filesystem (&g_fs);
@@ -249,11 +251,12 @@ volume_changed (GnomeVFSVolumeMonitor *volume_monitor,
 }
 
 void
-contents_changed_cb (GnomeVFSMonitorHandle *handle,
-		     const gchar *monitor_uri,
-		     const gchar *info_uri,
-		     GnomeVFSMonitorEventType event_type,
-		     gpointer user_data)
+contents_changed_cb (GFileMonitor      *file_monitor,
+              	     GFile             *child,
+              	     GFile             *other_file,
+              	     GFileMonitorEvent  event_type,
+              	     gpointer           user_data)
+
 {
 	gchar *excluding;
 
@@ -263,7 +266,7 @@ contents_changed_cb (GnomeVFSMonitorHandle *handle,
 	if (baobab.CONTENTS_CHANGED_DELAYED)
 		return;
 
-	excluding = g_path_get_basename (info_uri);
+	excluding = g_file_get_basename (child);
 	if (strcmp (excluding, ".recently-used") == 0   ||
 	    strcmp (excluding, ".gnome2_private") == 0  ||
 	    strcmp (excluding, ".xsession-errors") == 0 ||
@@ -287,35 +290,20 @@ void
 on_ck_allocated_activate (GtkCheckMenuItem *checkmenuitem,
 			  gpointer user_data)
 {
-	GdkCursor *cursor = NULL;
-
 	if (!baobab.is_local)
 		return;
 
 	baobab.show_allocated = gtk_check_menu_item_get_active (checkmenuitem);
 
-	/* change the cursor */
-	if (baobab.window->window) {
-		cursor = gdk_cursor_new (GDK_WATCH);
-		gdk_window_set_cursor (baobab.window->window, cursor);
-	}
-
 	baobab_treeview_show_allocated_size (baobab.tree_view,
 					     baobab.show_allocated);
 
-	set_busy (TRUE);
+	baobab_set_busy (TRUE);
 	set_statusbar (_("Calculating percentage bars..."));
 	gtk_tree_model_foreach (GTK_TREE_MODEL (baobab.model),
 				show_bars, NULL);
-	set_busy (FALSE);
+	baobab_set_busy (FALSE);
 	set_statusbar (_("Ready"));
-
-	/* cursor clean up */
-	if (baobab.window->window) {
-		gdk_window_set_cursor (baobab.window->window, NULL);
-		if (cursor)
-			gdk_cursor_unref (cursor);
-	}
 }
 
 void
@@ -348,28 +336,6 @@ on_view_sb_activate (GtkCheckMenuItem *checkmenuitem,
 			       NULL);
 }
 
-void
-on_menu_treemap_activate (GtkMenuItem *menuitem, gpointer user_data)
-{
-	GtkTreeIter iter;
-	GtkTreePath *path;
-	gchar *path_to_string;
-	
-	if (!gtk_tree_selection_get_selected (gtk_tree_view_get_selection 
-							(GTK_TREE_VIEW(baobab.tree_view)), 
-					      NULL, 
-					      &iter))		 
-		return;
-
-	path = gtk_tree_model_get_path(GTK_TREE_MODEL(baobab.model), &iter);
-	
-	/* path_to_string is freed in graph_map_cb function */
-	path_to_string = gtk_tree_path_to_string (path);
-
-	gtk_tree_path_free(path);
-	graph_map_cb(NULL, path_to_string);
-}
-
 void
 on_helpcontents_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
@@ -379,20 +345,19 @@ on_helpcontents_activate (GtkMenuItem *menuitem, gpointer user_data)
 void 
 scan_folder_cb (GtkMenuItem *pmenu, gpointer dummy)
 {
-	GnomeVFSURI *vfs_uri;
-
+	GFile	*file;
+	
 	g_assert (!dummy);
 	g_assert (baobab.selected_path);
 
-	vfs_uri = gnome_vfs_uri_new (baobab.selected_path);
+	file = g_file_parse_name (baobab.selected_path);
 
-	if (!gnome_vfs_uri_exists (vfs_uri)) {
+	if (!g_file_query_exists (file, NULL)) {
 		message (_("The folder does not exist."), "", GTK_MESSAGE_INFO, baobab.window);
 	}
 
-	gnome_vfs_uri_unref (vfs_uri);
-	
-	start_proc_on_dir (baobab.selected_path);
+	baobab_scan_location (file);
+	g_object_unref (file);
 }
 
 void
@@ -405,14 +370,15 @@ on_tv_selection_changed (GtkTreeSelection *selection, gpointer user_data)
                 
 		path = gtk_tree_model_get_path (GTK_TREE_MODEL (baobab.model), &iter);
                 
-		baobab_ringschart_set_root (baobab.ringschart, path);
+		baobab_chart_set_root (baobab.rings_chart, path);
+		baobab_chart_set_root (baobab.treemap_chart, path);
 		
 		gtk_tree_path_free (path);
 	}
 }
 
 void
-on_rchart_sector_activated (BaobabRingschart *rchart, GtkTreeIter *iter)
+on_chart_item_activated (BaobabChart *chart, GtkTreeIter *iter)
 {
 	GtkTreePath *path;
 
@@ -425,3 +391,92 @@ on_rchart_sector_activated (BaobabRingschart *rchart, GtkTreeIter *iter)
 				  path, NULL, FALSE);
 	gtk_tree_path_free (path);
 }
+
+gboolean
+on_chart_button_release (BaobabChart *chart, GdkEventButton *event,
+                          gpointer data)
+{
+  ContextMenu *menu;
+  
+  if (baobab_chart_is_frozen (baobab.current_chart))
+    return FALSE;
+
+  menu = baobab.chart_menu;
+  
+  if (event->button== 3) /* right button */
+    {
+      GtkTreePath *root_path = NULL;
+
+      root_path = baobab_chart_get_root (baobab.current_chart);
+
+      gtk_widget_set_sensitive (menu->up_item,
+                                ((root_path != NULL) &&
+                                 (gtk_tree_path_get_depth (root_path) > 1)));
+      gtk_widget_set_sensitive (menu->zoom_in_item,
+                                (baobab_chart_get_max_depth (baobab.current_chart) > 1));
+      gtk_widget_set_sensitive (menu->zoom_out_item,
+                               (baobab_chart_get_max_depth (baobab.current_chart) 
+                                < BAOBAB_CHART_MAX_DEPTH));
+
+      /* show the menu */
+      gtk_menu_popup (GTK_MENU (menu->widget), NULL, NULL, NULL, NULL,
+                      event->button, event->time);
+      
+      gtk_tree_path_free (root_path);
+    }
+ 
+  return FALSE;
+}
+
+void
+on_move_upwards_cb (GtkCheckMenuItem *checkmenuitem, gpointer user_data)
+{
+  baobab_chart_move_up_root (baobab.current_chart);
+}
+
+void
+on_zoom_in_cb (GtkCheckMenuItem *checkmenuitem, gpointer user_data)
+{
+  baobab_chart_zoom_in (baobab.current_chart);
+}
+
+void
+on_zoom_out_cb (GtkCheckMenuItem *checkmenuitem, gpointer user_data)
+{
+  baobab_chart_zoom_out (baobab.current_chart);
+}
+
+void
+on_chart_snapshot_cb (GtkCheckMenuItem *checkmenuitem, gpointer user_data)
+{
+  baobab_chart_save_snapshot (baobab.current_chart);
+}
+
+void
+on_chart_type_change (GtkWidget *combo, gpointer user_data)
+{
+  GtkWidget *chart;
+  GtkWidget *frame;
+
+  guint active;
+
+  active = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+  if (active == 0)
+    chart = baobab.rings_chart;
+  else
+    if (active == 1)
+      chart = baobab.treemap_chart;
+
+  frame = gtk_widget_get_parent (baobab.current_chart);
+
+  baobab_chart_freeze_updates (baobab.current_chart);
+  baobab_chart_thaw_updates (chart);
+
+  g_object_ref_sink (baobab.current_chart);
+  gtk_container_remove (GTK_CONTAINER (frame), baobab.current_chart);
+  gtk_container_add (GTK_CONTAINER (frame), chart);
+
+  baobab.current_chart = chart;
+}
+
